<?php

namespace Drupal\paragraph_lineage\Plugin\views\field;

use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\views\Annotation\ViewsField;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;

/**
 * Provides a custom field that links a file usage entity label to the paragraph admin view.
 *
 * @ViewsField("file_usage_paragraph_link")
 */
class FileUsageParagraphLink extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    // Retrieve the raw field value (the entity label).
    // Adjust the field key if necessary; this depends on your view configuration.
    $value = $this->getValue($values);
    // Get the label.
    $label = $value->label();

    // Get the type.
    $usage_type = $value->type();

    // Check if this usage is for a paragraph.
    if ($usage_type === 'paragraph') {
      // Assume the paragraph ID is stored in the 'id' field.
      $paragraph_id = $value->id();
      // Generate the URL to the paragraph admin view.
      $url = Url::fromRoute('entity.paragraph.canonical', ['paragraph' => $paragraph_id]);
      // Create a link from the label.
      $link = Link::fromTextAndUrl($label, $url);
      // Return the rendered link.
      return $link->toRenderable();
    }
    // Fallback: just return the label.
    return $label;
  }

}
